summaryrefslogtreecommitdiffstats
path: root/tdecore/kallocator.cpp
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 09:59:13 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 09:59:13 -0600
commit56160bf4dfe503631ef6373367b281f081bab2b4 (patch)
tree7fcea2ffd9c3420af999c3dcad0ed032eef93956 /tdecore/kallocator.cpp
parent13281e2856a2ef43bbab78c5528470309c23aa77 (diff)
downloadtdelibs-56160bf4dfe503631ef6373367b281f081bab2b4.tar.gz
tdelibs-56160bf4dfe503631ef6373367b281f081bab2b4.zip
Revert "Rename a number of old tq methods that are no longer tq specific"
This reverts commit 13281e2856a2ef43bbab78c5528470309c23aa77.
Diffstat (limited to 'tdecore/kallocator.cpp')
-rw-r--r--tdecore/kallocator.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/tdecore/kallocator.cpp b/tdecore/kallocator.cpp
index c02bbf3ff..16c1b3625 100644
--- a/tdecore/kallocator.cpp
+++ b/tdecore/kallocator.cpp
@@ -183,9 +183,9 @@ void KZoneAllocator::delBlock(MemBlock *b)
void *
KZoneAllocator::allocate(size_t _size)
{
- // Use the size of (void *) as alignment
- const size_t alignment = sizeof(void *) - 1;
- _size = (_size + alignment) & ~alignment;
+ // Use the size of (void *) as tqalignment
+ const size_t tqalignment = sizeof(void *) - 1;
+ _size = (_size + tqalignment) & ~tqalignment;
if ((unsigned long) _size + blockOffset > blockSize)
{